// ===========================================================================
// CONTENT  : INTERFACE StringFilter
// AUTHOR   : Manfred Duchrow
// VERSION  : 2.0 - 11/08/2014
// HISTORY  :
//  06/05/2005  mdu  CREATED
//  11/08/2014  mdu   added   --> NONE, ALL
//
// Copyright (c) 2005-2014, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.text;

// ===========================================================================
// IMPORTS
// ===========================================================================

/**
 * A simple interface for abstraction of string pattern matching
 *
 * @author Manfred Duchrow
 * @version 2.0
 */
public interface StringFilter
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  /**
   * A predefined filter that matches no string at all.
   */
  public static final StringFilter NONE = new StringFilter()
  {
    @Override
    public boolean matches(String aString)
    {
      return false;
    }
  };
  
  // -------------------------------------------------------------------------
  
  /**
   * A predefined filter that matches all strings (but not null).
   */
  public static final StringFilter ALL = new StringFilter()
  {
    @Override
    public boolean matches(String aString)
    {
      return aString != null;
    }
  };

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Returns true if the given string matches the filter otherwise false.
   * 
   * @param aString Any string or even null
   */
  public boolean matches(String aString);

} // interface StringFilter