// ===========================================================================
// CONTENT  : INTERFACE IReadOnlyNamedValues
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 11/08/2014
// HISTORY  :
//  11/08/2014  mdu  CREATED
//
// Copyright (c) 2014, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.facet ;

import java.util.Collection;

/**
 * Generic read only access to any name/value pair based containers where
 * the names are strings and the values can be any type.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IReadOnlyNamedValues<TValue>
{ 
  /**
   * Returns true if the receiver does not contain any data.
   */
  public boolean isEmpty();
  
  /**
   * Returns all names (maybe empty but never null).
   */
  public Collection<String> getNames();

  /**
   * Returns the value associated with the given name.
   * 
   * @param name The identifier for which the associated value must be returned (must not be null).
   * @return The values associated with the name or null if the name is unknown.
   */
  public TValue getValue(String name);
  
} // interface IReadOnlyNamedValues